==> expenselog_1.0.0.tar.gz: expenselog-1.0.0/src/file_category.h <==
/*
#dependencies not need, i hope:
#hildon-base-lib-dev, hildon-libs-dev, hildon-fm-dev, libosso-gnomevfs2-dev, libdbus-glib-1-dev, libosso-dev
Build-Depends:

*/

#ifndef file_category_h
#define file_category_h

#include <iostream>
#include <fstream>
#include <string>
#include <vector>
using namespace std;


/*
 * o arquivo de dados
 *
 */
#define assinaturya_arquivo_categoria "categories"

class file_category
{
	singleton(file_category)
	void _constructor() { }
	void _destructor() { }

private:
	//os nossos dados
	vector<string> _dados;
	//nome do arquivo
	string nome_do_arquivo;

public:
	vector<string> &dados()
	{
		return _dados;
	}

	bool inicializar(const char *arquivo)
	{
		nome_do_arquivo = arquivo;

		//se der erro, ignoramos homericaemnte, só registramos que nao incializou
		_dados.clear();

		filebuf fb;
		fb.open (nome_do_arquivo.c_str(),ios::in);
		istream is(&fb);
		string linha;
		getline(is, linha);
		if(linha != assinaturya_arquivo_categoria)
		{
			//erro!!!!
			fb.close();
			return false;
		}
		while(!is.eof())
		{
			getline(is, linha);
			if(linha != "")
				_dados.push_back(linha);
		}
		fb.close();
		return true;
	}

	bool salvar()
	{
		ofstream out(nome_do_arquivo.c_str(),
				ios::out | ios::binary | ios::trunc);
		if(!out)
			return false;

		out << assinaturya_arquivo_categoria;
		out << "\n";
		vector<string>::iterator it;
		for ( it=_dados.begin() ; it < _dados.end(); it++ )
		{
			out << (*it);
			out << "\n";
		}

		out.close();
		return true;
	}
};

#endif

==> expenselog_1.0.1.tar.gz: expenselog-1.0.1/src/file_category.h <==
/*
 * funciona:
Build-Depends: debhelper (>= 5), intltool, autotools-dev, libglib2.0-dev, libgtk2.0-dev,
  libgconf2-dev, libxdmcp-dev, x11proto-core-dev, libhildon1-dev, libcairo2-dev, libdbus-1-dev,
  libglib2.0-dev, libatk1.0-dev, libx11-dev, libfontconfig1-dev, libhildonfm2-dev, libxau-dev,
  libpixman-1-dev, libxrender-dev, libpng12-dev, x11proto-render-dev,
  libpango1.0-dev, libdbus-glib-1-dev

nao funciona:
Build-Depends: debhelper (>= 5), intltool, autotools-dev, libglib2.0-dev, libgtk2.0-dev,
  libxdmcp-dev, x11proto-core-dev, libhildon1-dev,
  libglib2.0-dev, libx11-dev, libxau-dev,
  libpixman-1-dev, libxrender-dev, libpng12-dev, x11proto-render-dev

 */

#ifndef file_category_h
#define file_category_h

#include <iostream>
#include <fstream>
#include <string>
#include <vector>
using namespace std;


/*
 * o arquivo de dados
 *
 */
#define assinaturya_arquivo_categoria "categories"

class file_category
{
	singleton(file_category)
	void _constructor() { }
	void _destructor() { }

private:
	//os nossos dados
	vector<string> _dados;
	//nome do arquivo
	string nome_do_arquivo;

public:
	vector<string> &dados()
	{
		return _dados;
	}

	bool inicializar(const char *arquivo)
	{
		nome_do_arquivo = arquivo;

		//se der erro, ignoramos homericaemnte, só registramos que nao incializou
		_dados.clear();

		filebuf fb;
		fb.open (nome_do_arquivo.c_str(),ios::in);
		istream is(&fb);
		string linha;
		getline(is, linha);
		if(linha != assinaturya_arquivo_categoria)
		{
			//erro!!!!
			fb.close();
			return false;
		}
		while(!is.eof())
		{
			getline(is, linha);
			if(linha != "")
				_dados.push_back(linha);
		}
		fb.close();
		return true;
	}

	bool salvar()
	{
		ofstream out(nome_do_arquivo.c_str(),
				ios::out | ios::binary | ios::trunc);
		if(!out)
			return false;

		out << assinaturya_arquivo_categoria;
		out << "\n";
		vector<string>::iterator it;
		for ( it=_dados.begin() ; it < _dados.end(); it++ )
		{
			out << (*it);
			out << "\n";
		}

		out.close();
		return true;
	}
};

#endif
